@@ -14,14 +14,13 @@ import (
 func TestReportWriter_Table(t *testing.T) {
 	testCases := []struct {
 		name               string
-		results            report.Results
+		results            types.Results
 		expectedOutput     string
-		light              bool
 		includeNonFailures bool
 	}{
 		{
 			name: "happy path full",
-			results: report.Results{
+			results: types.Results{
 				{
 					Target: "test",
 					Vulnerabilities: []types.DetectedVulnerability{
@@ -46,38 +45,11 @@ func TestReportWriter_Table(t *testing.T) {
 | foo     | CVE-2020-0001    | HIGH     | 1.2.3             | 3.4.5         | foobar                               |
 |         |                  |          |                   |               | -->avd.aquasec.com/nvd/cve-2020-0001 |
 +---------+------------------+----------+-------------------+---------------+--------------------------------------+
-`,
-		},
-		{
-			name:  "happy path light",
-			light: true,
-			results: report.Results{
-				{
-					Target: "test",
-					Vulnerabilities: []types.DetectedVulnerability{
-						{
-							VulnerabilityID:  "CVE-2020-0001",
-							PkgName:          "foo",
-							InstalledVersion: "1.2.3",
-							FixedVersion:     "3.4.5",
-							Vulnerability: dbTypes.Vulnerability{
-								Title:    "foobar",
-								Severity: "HIGH",
-							},
-						},
-					},
-				},
-			},
-			expectedOutput: `+---------+------------------+----------+-------------------+---------------+
-| LIBRARY | VULNERABILITY ID | SEVERITY | INSTALLED VERSION | FIXED VERSION |
-+---------+------------------+----------+-------------------+---------------+
-| foo     | CVE-2020-0001    | HIGH     | 1.2.3             | 3.4.5         |
-+---------+------------------+----------+-------------------+---------------+
 `,
 		},
 		{
 			name: "no title for vuln and missing primary link",
-			results: report.Results{
+			results: types.Results{
 				{
 					Target: "test",
 					Vulnerabilities: []types.DetectedVulnerability{
@@ -103,7 +75,7 @@ func TestReportWriter_Table(t *testing.T) {
 		},
 		{
 			name: "long title for vuln",
-			results: report.Results{
+			results: types.Results{
 				{
 					Target: "test",
 					Vulnerabilities: []types.DetectedVulnerability{
@@ -132,7 +104,7 @@ func TestReportWriter_Table(t *testing.T) {
 		},
 		{
 			name: "happy path misconfigurations",
-			results: report.Results{
+			results: types.Results{
 				{
 					Target: "test",
 					Misconfigurations: []types.DetectedMisconfiguration{
@@ -171,7 +143,7 @@ func TestReportWriter_Table(t *testing.T) {
 		{
 			name:               "happy path misconfigurations with successes",
 			includeNonFailures: true,
-			results: report.Results{
+			results: types.Results{
 				{
 					Target: "test",
 					Misconfigurations: []types.DetectedMisconfiguration{
@@ -215,10 +187,9 @@ func TestReportWriter_Table(t *testing.T) {
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
 			tableWritten := bytes.Buffer{}
-			err := report.Write(report.Report{Results: tc.results}, report.Option{
+			err := report.Write(types.Report{Results: tc.results}, report.Option{
 				Format:             "table",
 				Output:             &tableWritten,
-				Light:              tc.light,
 				IncludeNonFailures: tc.includeNonFailures,
 			})
 			assert.NoError(t, err)
